@@ -31,7 +31,7 @@ APP_PATH="/usr/share/applications/easycrypt.desktop"
 WEBSITE="http://www.squeezedonkey.com/wiki/linux/index.php?title=EasyCrypt"
 CMD_TEST_TRUECRYPT="which truecrypt"
 CMD_TEST_TRUECRYPT_VERSION_43a="truecrypt --version"
-CMD_TEST_TRUECRYPT_VERSION_5x="truecrypt -t --version"
+CMD_TEST_TRUECRYPT_VERSION_6x="truecrypt -t --version"
 
 BASIC_SUDO_COMMAND = "sudo"
 URL_TRUECRYPT_DOWNLOAD="http://www.truecrypt.org/downloads.php"
@@ -331,7 +331,7 @@ class EasyCrypt:
 
 	def __init__(self):
 		debug_begin('function __init__ EasyCrypt')
-		self.version = "0.2.2.10"
+		self.version = "0.2.3.1"
 		debug("Easy Crypt "+self.version+" ("+time.strftime("%Y/%m/%d %H:%M:%S", time.localtime())+")")
 		debug("root is " + self.root)
 		self.isExpert = False
@@ -352,6 +352,8 @@ class EasyCrypt:
 		self.hasTrueCryptV5_0 = False
 		self.hasTrueCryptV5_1 = False
 		self.hasTrueCryptV5_X = False
+		self.hasTrueCryptV6_1 = False
+		self.hasTrueCryptV6_X = False
 		self.truecrypt_high_version = ""
 		
 		needToSeeWelcome = False
@@ -582,7 +584,7 @@ class EasyCrypt:
 			debug_end('function getTextForCommandChange')
 			return "truecrypt --o --random-source "+crypt_rand+" -C " +cryptLocation				
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				debug_end('function getTextForCommandChange')
 				return "truecrypt -t --random-source="+crypt_rand+" -C " +cryptLocation
 		debug_end('function getTextForCommandChange')
@@ -594,7 +596,7 @@ class EasyCrypt:
 			debug_end('function getTextForCommandCreate')
 			return "truecrypt --disable-progress --encryption "+encType+" --hash "+hashType+" --filesystem "+fsType+" --size "+sizeInMB+" --type normal --random-source "+crypt_rand+" --o -c "+cryptLocation				
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				debug_end('function getTextForCommandCreate')
 				return "truecrypt -t --encryption="+encType+" --hash="+hashType+" --filesystem="+fsType+" --size="+targetSizeInBytes+" --random-source="+crypt_rand+" -c "+cryptLocation				
 		debug_end('function getTextForCommandCreate')
@@ -606,7 +608,7 @@ class EasyCrypt:
 			debug_end('function getTextForCommandClose')
 			return "truecrypt -d"				
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				debug_end('function getTextForCommandClose')
 				return "truecrypt -t -d"
 		debug_end('function getTextForCommandClose')
@@ -618,7 +620,7 @@ class EasyCrypt:
 			debug_end('function getTextForCommandListOpened')
 			return self.sudo_command+" \"truecrypt -l\""				
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				debug_end('function getTextForCommandListOpened')
 				return "truecrypt -t -l"
 		debug_end('function getTextForCommandListOpened')
@@ -634,7 +636,7 @@ class EasyCrypt:
 				debug_end('function getTextForCommandOpen')
 				return "truecrypt -i"				
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				if asUser:
 					debug_end('function getTextForCommandOpen')
 					return "truecrypt -t --mount"
@@ -650,29 +652,44 @@ class EasyCrypt:
 		self.hasTrueCryptV5_0 = False
 		self.hasTrueCryptV5_1 = False
 		self.hasTrueCryptV5_X = False
+		self.hasTrueCryptV6_1 = False
 		self.truecrypt_high_version = ""
-		outputString = commands.getoutput(CMD_TEST_TRUECRYPT_VERSION_5x)
-		if outputString == "TrueCrypt 5.1" :
-			debug("found 5.1")
-			debug("detected 5.1")
-			self.hasTrueCryptV5_1 = True
+		outputString = commands.getoutput(CMD_TEST_TRUECRYPT_VERSION_6x)
+		if outputString == "TrueCrypt 6.1" :
+			debug("found 6.1")
+			debug("detected 6.1")
+			self.hasTrueCryptV6_1 = True
 		else :
-			if outputString == "TrueCrypt 5.0" :
-				debug("detected 5.0")
-				self.hasTrueCryptV5_0 = True
+			if outputString == "TrueCrypt 6.0a" :
+				debug("found 6.0a")
+				debug("detected 6.0a")
+				self.hasTrueCryptV6_1 = True
 			else :
-				if outputString.find("TrueCrypt 5.") > -1 :
-					debug("detected 5.x")
-					self.hasTrueCryptV5_X = True
-					self.truecrypt_high_version = outputString.replace("TrueCrypt ","",1)
-				else:
-					outputString = commands.getoutput(CMD_TEST_TRUECRYPT_VERSION_43a)
-					lines = outputString.splitlines(False)
-					if len(lines) > 0 :
-						debug("got enough lines")
-						if lines[0] == "truecrypt 4.3a" :
-							debug("detected 4.3")
-							self.hasTrueCryptV4_3a = True
+				if outputString.find("TrueCrypt 6.1") > -1:
+					debug("found 6.X")
+					self.hasTrueCryptV6_X = True
+				else :
+					if outputString == "TrueCrypt 5.1" :
+						debug("found 5.1")
+						debug("detected 5.1")
+						self.hasTrueCryptV5_1 = True
+					else :
+						if outputString == "TrueCrypt 5.0" :
+							debug("detected 5.0")
+							self.hasTrueCryptV5_0 = True
+						else :
+							if outputString.find("TrueCrypt 5.") > -1 :
+								debug("detected 5.x")
+								self.hasTrueCryptV5_X = True
+								self.truecrypt_high_version = outputString.replace("TrueCrypt ","",1)
+							else:
+								outputString = commands.getoutput(CMD_TEST_TRUECRYPT_VERSION_43a)
+								lines = outputString.splitlines(False)
+								if len(lines) > 0 :
+									debug("got enough lines")
+									if lines[0] == "truecrypt 4.3a" :
+										debug("detected 4.3")
+										self.hasTrueCryptV4_3a = True
 		debug_end('function determinTruecryptVersion')
 	
 	def lookForTruecrypt(self):
@@ -735,7 +752,7 @@ class EasyCrypt:
 					else:
 						debug("red herring")
 		else:
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				for v in lines:
 					debug("current mount " + v)
 					location = v.find(decodeFilePath(cryptLocation)+" ")
@@ -824,7 +841,7 @@ class EasyCrypt:
 		if self.hasTrueCryptV4_3a:
 			opener = TrueCryptCommandRunner4_3a(BASIC_SUDO_COMMAND+" "+commandOpenAsUser,decodeFilePath(cryptLocation),decodeFilePath(mountPoint), password, "",self.selectedKeyFile , "", "open")
 		else :
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				opener = TrueCryptCommandRunner5_1(BASIC_SUDO_COMMAND+" "+commandOpenAsUser,decodeFilePath(cryptLocation),decodeFilePath(mountPoint), password, "",self.selectedKeyFile , "", "open")
 		opener.start()		
 		while not opener.doneRunning :
@@ -869,7 +886,7 @@ class EasyCrypt:
 						debug("possible line " + lines[0])
 						mountPoint = lines[0]
 					else :
-						if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+						if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 							debug("possible line " + lines[1])
 							mountPoint = lines[1]
 			
@@ -975,7 +992,7 @@ class EasyCrypt:
 		if self.hasTrueCryptV4_3a:
 			maker = TrueCryptCommandRunner4_3a(commandToRun,cryptLocation,"", password, "", keyfilePath, "", "create")
 		else :
-			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+			if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 				maker = TrueCryptCommandRunner5_1(commandToRun,cryptLocation,"", password, "", keyfilePath, "", "create")
 		maker.start()
 		
@@ -1048,7 +1065,7 @@ class EasyCrypt:
 				debug("possible line " + lines[0])
 				mountPoint = lines[0]
 			else :
-				if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+				if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 					debug("possible line " + lines[2])
 					mountPoint = lines[2]
 			
@@ -1103,9 +1120,9 @@ class EasyCrypt:
 				if self.hasTrueCryptV4_3a:
 					changer = TrueCryptCommandRunner4_3a(commandToRun, cryptLocation, "", password,newPassword,keyfilePath,keyfilePathNew, "change")
 				else :
-					if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+					if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 						changer = TrueCryptCommandRunner5_1(commandToRun, cryptLocation, "", password,newPassword,keyfilePath,keyfilePathNew, "change")
-				if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+				if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 					self.closeCrypt(False)
 				
 				changer.start()
@@ -1130,7 +1147,7 @@ class EasyCrypt:
 					self.textbox_change_password_current.set_text("")
 					self.textbox_change_password_current.grab_focus()
 				else :
-					if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X:
+					if self.hasTrueCryptV5_1 or self.hasTrueCryptV5_X or self.hasTrueCryptV6_1 or self.hasTrueCryptV6_X:
 						self.textbox_password_value = newPassword
 						self.selectedKeyFile = keyfilePathNew
 						self.openCrypt(True,True)
@@ -1878,6 +1895,12 @@ class EasyCrypt:
 				else :
 					if self.hasTrueCryptV5_X:
 						truecryptDetectionText = _("Detected TrueCrypt Version") + ": " + self.truecrypt_high_version
+					else :
+						if self.hasTrueCryptV6_1:
+							truecryptDetectionText = _("Detected TrueCrypt Version") + ": 6.1"
+						else :
+							if self.hasTrueCryptV6_X:
+								truecryptDetectionText = _("Detected TrueCrypt Version") + ": 6.X"
 					
 		label_blurb.set_markup('\n<span size="larger" weight="bold">'+_("Written by Steven Harper")+'</span>\n\n'+_("Uses the most Excellent Truecrypt")+'\n\n'+truecryptDetectionText+'\n')
 		table.attach(label_blurb,  0, 1, 4, 5,xpadding=2,ypadding=1)
